@@ -125,7 +125,7 @@ pub fn mult() -> Term {
 
 /// Applied to two Church-encoded numbers it raises the first one to the power of the second one.
 ///
-/// POW := λbe.IF_ELSE (IS_ZERO e) ONE (e b) = λ λ IF_ELSE (IS_ZERO 1) ONE (1 2)
+/// POW := λbe.IS_ZERO e ONE (e b) = λ λ IS_ZERO 1 ONE (1 2)
 ///
 /// # Example
 /// ```
@@ -138,8 +138,8 @@ pub fn mult() -> Term {
 /// ```
 pub fn pow() -> Term {
     abs(abs(
-        if_else()
-        .app(is_zero().app(Var(1)))
+        is_zero()
+        .app(Var(1))
         .app(one())
         .app(Var(1).app(Var(2)))
     ))
@@ -323,7 +323,7 @@ pub fn gt() -> Term {
 }
 
 /// Applied to two Church-encoded numbers it returns a Church-encoded pair with the result of their
-/// division - the quotient and the remainder.
+/// division - the quotient and the remainder. It loops indefinitely if the divisor is `zero()`.
 ///
 /// DIV := Y (λgqab.LT a b (PAIR q a) (g (SUCC q) (SUB a b) b)) ZERO =
 /// Y (λ λ λ λ LT 2 1 (PAIR 3 2) (4 (SUCC 3) (SUB 2 1) 1)) ZERO
@@ -358,6 +358,7 @@ pub fn div() -> Term {
 }
 
 /// Applied to two Church-encoded numbers it returns a Church-encoded quotient of their division.
+/// It loops indefinitely if the second argument is `zero()`.
 ///
 /// QUOT := Y (λrab.LT a b ZERO (SUCC (r (SUB a b) b))) =
 /// Y (λ λ λ LT 2 1 ZERO (SUCC (3 (SUB 2 1) 1)))
@@ -395,6 +396,7 @@ pub fn quot() -> Term {
 
 // TODO: find an independent variant, like with quot()
 /// Applied to two Church-encoded numbers it returns a Church-encoded remainder of their division.
+/// It loops indefinitely if the second argument is `zero()`.
 ///
 /// REM := λab. SECOND (DIV a b) = λ λ SECOND (DIV 2 1)
 ///
@@ -417,6 +419,38 @@ pub fn rem() -> Term {
     ))
 }
 
+/// Applied to a Church-encoded number it yields its Church-encoded factorial.
+///
+/// FACTORIAL := Y (λgx. ISZERO x ONE (MULT x (g (PRED x)))) = 
+/// Y (λ λ ISZERO 1 ONE (MULT 1 (2 (PRED 1))))
+///
+/// # Example
+/// ```
+/// use lambda_calculus::arithmetic::factorial;
+///
+/// let mut expr = factorial().app(3.into());
+/// expr.beta_full();
+///
+/// assert_eq!(expr, 6.into());
+/// ```
+pub fn factorial() -> Term {
+    y()
+    .app(
+        abs(abs(
+            is_zero()
+            .app(Var(1))
+            .app(one())
+            .app(
+                mult()
+                .app(Var(1))
+                .app(
+                    Var(2).app(pred().app(Var(1)))
+                )
+            )
+        ))
+    )
+}
+
 impl Term {
     /// Returns the value of `self` if it's a Church-encoded number.
     ///
@@ -555,4 +589,12 @@ mod test {
         assert_eq!(beta_full(rem().app(0.into()).app(3.into())), 0.into());
         // assert_eq!(beta_full(quot().app(1.into()).app(0.into())), ); division by 0 hangs
     }
+    
+    #[test]
+    fn church_factorial() {
+        assert_eq!(beta_full(factorial().app(0.into())), 1.into());
+        assert_eq!(beta_full(factorial().app(1.into())), 1.into());
+        assert_eq!(beta_full(factorial().app(2.into())), 2.into());
+        assert_eq!(beta_full(factorial().app(3.into())), 6.into());
+    }
 }
