@@ -12,6 +12,7 @@
 
 use term::*;
 use term::Term::*;
+use reduction::{EVALUATION_ORDER, Order};
 
 /// I - the identity combinator.
 ///
@@ -176,7 +177,7 @@ pub fn omm() -> Term { om().app(om()) }
 
 /// Y - the fixed-point combinator.
 ///
-/// Y := λg.(λx.g (x x)) (λx.g (x x)) = λ (λ 2 (1 1)) (λ 2 (1 1))
+/// Y := λf.(λx.f (x x)) (λx.f (x x)) = λ (λ 2 (1 1)) (λ 2 (1 1))
 ///
 /// # Example
 /// ```
@@ -187,10 +188,22 @@ pub fn omm() -> Term { om().app(om()) }
 /// assert_eq!(beta_full(y().app(zero())), beta_full(zero().app(y().app(zero()))));
 /// ```
 pub fn y() -> Term {
-    abs(app(
-        abs(Var(2).app(Var(1).app(Var(1)))),
-        abs(Var(2).app(Var(1).app(Var(1))))
-    ))
+    match EVALUATION_ORDER {
+        Order::Normal => {
+            abs(app(
+                abs(Var(2).app(Var(1).app(Var(1)))),
+                abs(Var(2).app(Var(1).app(Var(1))))
+            ))
+        }
+        Order::Applicative => { /* should any variant work with applicative order? */
+            panic!("Y combinator won't work with applicative order")
+            //parse(&"(λλ212)(λλ2(121))").unwrap()
+            //parse(&"(λλ(1(λ3321)))(λλ(1(λ3321)))").unwrap()
+            //parse(&"(λ11)(λ(λ(3(22)1)))").unwrap()
+            //parse(&"λ(λ(2(λ(221))))(λ(2(λ(221))))").unwrap()
+            //parse(&"λ(λ11)(λ(2(λ((22)1))))").unwrap()
+        }
+    }
 }
 
 /// T - the thrush combinator
