@@ -9,7 +9,8 @@ use arithmetic::{zero, succ};
 use combinators::y;
 use std::ops::Index;
 
-/// Equivalent to `fls()`; produces a Church-encoded `nil`, the last link of a Church-encoded list.
+/// Equivalent to `booleans::fls()`; produces a Church-encoded `nil`, the last link of a 
+/// Church-encoded list.
 ///
 /// NIL := FALSE
 ///
@@ -42,7 +43,7 @@ pub fn null() -> Term {
     )
 }
 
-/// Equivalent to `pair()`; applied to two terms it returns them contained in a Church-encoded list.
+/// Equivalent to `pair::pair()`; applied to two terms it returns them contained in a Church-encoded list.
 ///
 /// CONS := PAIR
 ///
@@ -72,7 +73,7 @@ pub fn null() -> Term {
 /// ```
 pub fn cons() -> Term { pair() }
 
-/// Equivalent to `first()`; applied to a Church-encoded list it returns its first element.
+/// Equivalent to `pair::first()`; applied to a Church-encoded list it returns its first element.
 ///
 /// HEAD := FIRST
 ///
@@ -89,7 +90,7 @@ pub fn cons() -> Term { pair() }
 /// ```
 pub fn head() -> Term { first() }
 
-/// Equivalent to `second()`; applied to a Church-encoded list it returns a new list with all its
+/// Equivalent to `pair::second()`; applied to a Church-encoded list it returns a new list with all its
 /// elements but the first one.
 ///
 /// TAIL := SECOND
@@ -208,6 +209,69 @@ pub fn list() -> Term {
     )
 }
 
+/// Applied to 2 Church-encoded lists it concatenates them.
+///
+/// APPEND := Y (λgab. NULL a b (PAIR (FIRST a) (g (SECOND a) b))) =
+/// Y (λ λ λ NULL 2 1 (PAIR (FIRST 2) (3 (SECOND 2) 1)))
+///
+/// # Example
+/// ```
+/// use lambda_calculus::term::Term;
+/// use lambda_calculus::list::append;
+/// use lambda_calculus::reduction::beta_full;
+///
+/// let list1 = Term::from(vec![0.into(), 1.into()]);
+/// let list2 = Term::from(vec![2.into(), 3.into()]);
+///
+/// assert_eq!(beta_full(append().app(list1).app(list2)),
+///            Term::from(vec![0.into(), 1.into(), 2.into(), 3.into()]));
+/// ```
+pub fn append() -> Term {
+    y()
+    .app(
+        abs(abs(abs(
+            null()
+            .app(Var(2))
+            .app(Var(1))
+            .app(
+                pair()
+                .app(first().app(Var(2)))
+                .app(
+                    Var(3)
+                    .app(second().app(Var(2)))
+                    .app(Var(1))
+                )
+            )
+        )))
+    )
+}
+
+/// Applied to a Church-encoded number `i` and a Church-encoded list it returns the `i`-th 
+/// (zero-indexed) element of the list.
+///
+/// INDEX := λix. FIRST (x SECOND i) = λ λ FIRST (2 SECOND 1)
+///
+/// # Example
+/// ```
+/// use lambda_calculus::term::Term;
+/// use lambda_calculus::list::index;
+/// use lambda_calculus::reduction::beta_full;
+///
+/// let list = Term::from(vec![3.into(), 4.into(), 5.into()]);
+///
+/// assert_eq!(beta_full(index().app(0.into()).app(list.clone())), 3.into());
+/// assert_eq!(beta_full(index().app(2.into()).app(list)        ), 5.into());
+/// ```
+pub fn index() -> Term {
+    abs(abs(
+        first().app(
+            Var(2)
+            .app(second())
+            .app(Var(1))
+        )
+    ))
+}
+
 impl Term {
     /// Checks whether self is a Church-encoded empty list, i.e. `nil()`.
     ///
@@ -453,7 +517,7 @@ impl Term {
     /// assert_eq!(list_110, Term::from(vec![one(), zero()]));
     /// ```
     pub fn pop(&mut self) -> Result<Term, Error> {
-        let (head, tail) = try!(self.clone().uncons()); // TODO: drop clone()
+        let (head, tail) = try!(self.clone().uncons()); // TODO: drop clone()?
         *self = tail;
 
         Ok(head)
@@ -490,7 +554,7 @@ impl Index<usize> for Term {
     fn index(&self, i: usize) -> &Self::Output {
         if !self.is_list() { panic!("attempting to index something that is not a list!") }
 
-        if i == 0 { return self.head_ref().unwrap() } // safe - checked above
+        if i == 0 { return self.head_ref().unwrap() } // safe - guaranteed by is_list()
 
         let mut candidate = self.snd_ref().expect("index out of bounds!");
 
@@ -498,7 +562,7 @@ impl Index<usize> for Term {
             candidate = candidate.snd_ref().expect("index out of bounds!")
         }
 
-        candidate.head_ref().unwrap()
+        candidate.head_ref().unwrap() // safe - verified as valid by is_list()
     }
 }
 
@@ -509,17 +573,25 @@ mod test {
 
     #[test]
     fn empty_list() {
-        let nil = nil();
-
-        assert!(!nil.is_list());
-        assert!(nil.is_empty());
+        assert!(!nil().is_list());
+        assert!(nil().is_empty());
     }
 
     #[test]
     fn list_push() {
         let list_pushed = nil().push(0.into()).push(1.into()).push(1.into());
         let list_consed = beta_full(
-            cons().app(1.into()).app(cons().app(1.into()).app(cons().app(0.into()).app(nil())))
+            cons()
+            .app(1.into())
+            .app(
+                cons()
+                .app(1.into())
+                .app(
+                    cons()
+                    .app(0.into())
+                    .app(nil())
+                )
+            )
         );
 
         assert_eq!(list_pushed, list_consed);
