@@ -6,6 +6,13 @@ use std::fmt;
 use std::borrow::Cow;
 use std::char::from_u32;
 
+/// Set to `true` for λ or `false` for \ when displaying lambda terms. The default is `true`.
+pub const DISPLAY_PRETTY: bool = true;
+
+/// Set to `true` for classic lambda mode or `false` for the De Bruijn index display mode when
+/// displaying lambda terms. The default is `false`.
+pub const DISPLAY_CLASSIC: bool = false;
+
 /// A lambda term that is either a variable with a De Bruijn index, an abstraction over a term or
 /// an applicaction of one term to another.
 #[derive(Debug, PartialEq, Clone)]
@@ -257,13 +264,6 @@ pub fn abs(term: Term) -> Term { Abs(Box::new(term)) }
 /// ```
 pub fn app(lhs: Term, rhs: Term) -> Term { App(Box::new(lhs), Box::new(rhs)) }
 
-/// Set to `true` for λ or `false` for \ when displaying lambda terms. The default is `true`.
-pub const DISPLAY_PRETTY: bool = true;
-
-/// Set to `true` for classic lambda mode or `false` for the De Bruijn index display mode when
-/// displaying lambda terms. The default is `false`.
-pub const DISPLAY_CLASSIC: bool = false;
-
 impl fmt::Display for Term {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(f, "{}", show_precedence(self, 0, 0))
@@ -275,11 +275,7 @@ impl fmt::Display for Term {
 pub fn show_precedence(term: &Term, context_precedence: usize, depth: u32) -> String {
     match *term {
         Var(i) => if DISPLAY_CLASSIC {
-            format!("{}", if i <= depth as usize {
-                from_u32(depth + 97 - i as u32).unwrap()
-            } else {
-                from_u32(depth + 96 + i as u32).unwrap()
-            })
+            format!("{}", from_u32(depth + 97 - i as u32).unwrap())
         } else {
             format!("{:X}", i)
         },
